@@ -22,6 +22,11 @@ cost = 1 #Price of usage
 #Change the items on the slot spinner or the number of items.
 slotlist = ["Club", "Staff", "Shield", "Sword", "Wand", "Scroll", "JackPot"]
 
+#Pay for minor and major wins.
+#Major as percent of pot. Minor as how many times cost
+slotminor = [1, 2, 3, 4, 5, 10, 20]
+slotmajor = [.10, .15, .20, .25, .35, .50, 1]
+
 spinners = 4 #How many spinners on the slotmachine?
 
 
@@ -36,27 +41,16 @@ if (activator.PayAmount(cost*10)):#goldcoin
    for item in results:
       #match all but one - pays out by coin e.g 3 to 1 or 4 to 1
       if results.count(item) == spinners-1:
-         if item == "Club":
-            pay = 1
-         elif item == "Staff":
-            pay = 2
-         elif item == "Shield":
-            pay = 3
-         elif item == "Sword":
-            pay = 4
-         elif item == "Wand":
-            pay = 5
-         elif item == "Scroll":
-            pay = 10
-         elif item == "JackPot":
-            pay = 20
+         if item in slotlist:
+            pay = slotminor[slotlist.index(item)]
          else:
-	    break
+            break
 	 activator.Write("%d %ss, a minor win!" %(spinners-1,item))
          payoff = cost*pay
          Slots.payoff(payoff)
-         id = activator.Map.CreateObject(cointype, x, y)
-         CFItemBroker.Item(id).add(payoff)
+         id = Crossfire.CreateObjectByName(cointype)
+         id.Quantity = payoff
+         id.InsertInto(activator)
          if payoff == 1:
             message = "you win %d %s!" %(payoff,cointype)
 	 else:
@@ -65,24 +59,15 @@ if (activator.PayAmount(cost*10)):#goldcoin
       elif results.count(item) == spinners:
          #all match - pays out as percent of pot
          activator.Write('%d %ss, a Major win!' %(spinners,item))
-         if item == "Club":
-            pay = .10
-         elif item == "Staff":
-            pay = .15
-         elif item == "Shield":
-            pay = .20
-         elif item == "Sword":
-            pay = .25
-         elif item == "Wand":
-            pay = .35
-         elif item == "Scroll":
-            pay = .50
-         elif item == "JackPot":
-            pay = 1
+         if item in slotlist:
+            pay = slotmajor[slotlist.index(item)]
+         else:
+            break
          payoff = pot*pay
          Slots.payoff(payoff)
-         id = activator.Map.CreateObject(cointype, x, y)
-         CFItemBroker.Item(id).add(payoff)
+         id = Crossfire.CreateObjectByName(cointype)
+         id.Quantity = payoff
+         id.InsertInto(activator)
 	 if payoff == 1:
             message = "you win %d %s!" %(payoff,cointype)
 	 else:
